KOTAI_CODE_OFFSET=40

base_board_eeprom_read() {
	# convert from i2cget little endian to big endian
	i2cget -y 1 0x50 "$1" w \
		| sed -e 's/0x\(..\)\(..\)/0x\2\1/'
}

base_board_is_atmark_techno() {
	case "$(base_board_eeprom_read 0x00)" in
	"") error "eeprom could not be read";;
	0xffff) error "eeprom is not initialized, please setup it.";;
	0x0001) return 0;;
	esac
	# not atmark techno
	return 1
}

base_board_read_product_id() {
	base_board_eeprom_read 0x02
}

base_board_read_revision() {
	base_board_eeprom_read 0x0A
}

board_setup() {
	if ! base_board_is_atmark_techno; then
		return 0
	fi

	local board="$(base_board_read_revision)"
	einfo "board = $board"
	case "$board" in
	"") error "eeprom could not be read (revision)";;
	0xffff) error "eeprom revision is not initialized";;
	0x0001) echo 'iot-a6e-es1 at1';;
	0x0002) echo 'iot-a6e-es2 at1';;
	0x0003) echo 'iot-a6e at1';;
	*) echo 'unknown-board at1';;
	esac > /target/etc/hwrevision \
		|| error "Could not update /etc/hwrevision"

	local product_id="$(base_board_read_product_id)"
	einfo "product_id = $product_id"
	case "$product_id" in
	"") error "eeprom could not be read (product_id)";;
	0xffff) error "eeprom product_id is not initialized";;
	0x0001)
		einfo "EMS31 exists"
		enable_overlay armadillo-iotg-a6e-ems31.dtbo
		ln -sf /etc/init.d/ems31-boot /target/etc/runlevels/boot/ \
			|| error "Could not enable ems31-boot service"
		ln -sf /etc/init.d/wwan-led /target/etc/runlevels/default/ \
			|| error "Could not enable wwan-led service"
		;;
	0x0002)
		einfo "EMS31 & lwb5plus exists"
		enable_overlay armadillo-iotg-a6e-ems31.dtbo \
			armadillo-iotg-a6e-lwb5plus.dtbo
		ln -sf /etc/init.d/ems31-boot /target/etc/runlevels/boot/ \
			|| error "Could not enable ems31-boot service"
		ln -sf /etc/init.d/wwan-led /target/etc/runlevels/default/ \
			|| error "Could not enable wwan-led service"
		;;
	0x0003)
		einfo "ELS31 exists"
		enable_overlay armadillo-iotg-a6e-els31.dtbo
		ln -sf /etc/init.d/connection-recover /target/etc/runlevels/default/ \
			|| error "Could not enable connection-recover service"
		ln -sf /etc/init.d/modemmanager /target/etc/runlevels/boot/ \
			|| error "could not enable modemmanager service"
		;;
	0x0004)
		einfo "ELS31 & lwb5plus exists"
		enable_overlay armadillo-iotg-a6e-els31.dtbo \
			armadillo-iotg-a6e-lwb5plus.dtbo
		ln -sf /etc/init.d/connection-recover /target/etc/runlevels/default/ \
			|| error "Could not enable connection-recover service"
		ln -sf /etc/init.d/modemmanager /target/etc/runlevels/boot/ \
			|| error "could not enable modemmanager service"
		;;
	0x0006)
		einfo "lwb5plus exists"
		enable_overlay armadillo-iotg-a6e-lwb5plus.dtbo
		;;
	esac
}
